@@ -33,7 +33,7 @@ from brewtils.models import (
     RequestFile,
     RequestTemplate,
     Resolvable,
-    Role,
+    LegacyRole,
     Runner,
     System,
 )
@@ -298,7 +298,7 @@ def assert_role_equal(obj1, obj2, do_raise=False):
     return _assert_wrapper(
         obj1,
         obj2,
-        expected_type=Role,
+        expected_type=LegacyRole,
         deep_fields={"roles": partial(assert_role_equal, do_raise=True)},
         do_raise=do_raise,
     )
@@ -330,6 +330,34 @@ def assert_job_equal(obj1, obj2, do_raise=False):
     )
 
 
+def assert_job_ids_equal(dict1, dict2, do_raise=False):
+    try:
+        assert (
+            isinstance(dict1, dict) and "ids" in dict1
+        ), "Not a job ID dict: %s" % str(dict1)
+        assert (
+            isinstance(dict2, dict) and "ids" in dict2
+        ), "Not a job ID dict: %s" % str(dict2)
+
+        lst1, lst2 = dict1.get("ids", None), dict2.get("ids", None)
+
+        assert lst1 is not None and lst2 is not None, "ID list is 'None'"
+        assert isinstance(lst1, list) and isinstance(
+            lst2, list
+        ), "ID list is not a list"
+        assert len(lst1) == len(lst1), "ID lists different lengths"
+
+        for str1, str2 in zip(sorted(lst1), sorted(lst2)):
+            assert isinstance(str1, str), "Not a job ID string: %s" % str(str1)
+            assert isinstance(str2, str), "Not a job ID string: %s" % str(str2)
+            assert str1 == str2, "Unequal job ID strings: %s/%s" % (str1, str2)
+    except AssertionError:
+        if do_raise:
+            raise
+        return False
+    return True
+
+
 def assert_operation_equal(obj1, obj2, do_raise=False):
 
     _assert(obj1.model_type == obj2.model_type, "Model types were not equal")
